;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cape" "2.6"
  "Completion At Point Extensions."
  '((emacs  "29.1")
    (compat "30"))
  :url "https://github.com/minad/cape"
  :commit "2b2a5c5bef16eddcce507d9b5804e5a0cc9481ae"
  :revdesc "2.6-0-g2b2a5c5bef16"
  :keywords '("abbrev" "convenience" "matching" "completion" "text")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
